﻿using Microsoft.VisualBasic.FileIO;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Atelier.Forms
{
    public partial class FormFabric : Form
    {
        private readonly IFabricRepository _fabricRepository;
        private int? _fabricId;

        public FormFabric(IFabricRepository fabricRepository)
        {
            InitializeComponent();
            _fabricRepository = fabricRepository ?? throw new ArgumentNullException(nameof(fabricRepository));
            comboBoxFabric.DataSource = Enum.GetValues(typeof(FabricType));

            // Инициализация CheckedListBox
            foreach (Color elem in Enum.GetValues(typeof(Color)))
            {
                checkedListBoxColor.Items.Add(elem);
            }

            // Отладочный вывод
            foreach (var item in checkedListBoxColor.Items)
            {
                Console.WriteLine(item);
            }
        }

        public int Id
        {
            set
            {
                try
                {
                    var fabric = _fabricRepository.ReadFabricById(value);
                    if (fabric == null)
                    {
                        throw new InvalidDataException(nameof(fabric));
                    }

                    comboBoxFabric.SelectedItem = fabric.FabricType;
                    foreach (Color elem in Enum.GetValues(typeof(Color)))
                    {
                        if ((elem & fabric.Color) != 0)
                        {
                            checkedListBoxColor.SetItemChecked(checkedListBoxColor.Items.IndexOf(elem), true);
                        }
                    }
                    numericUpDownMetrage.Value = (decimal)fabric.Metrage;

                    _fabricId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }
       
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (comboBoxFabric.SelectedIndex < 0.50 || checkedListBoxColor.CheckedItems.Count == 0)
                {
                    throw new Exception("Имеются незаполненные поля");
                }
                if (_fabricId.HasValue)
                {
                    _fabricRepository.UpdateFabric(CreateFabric(_fabricId.Value));
                }
                else
                {
                    _fabricRepository.CreateFabric(CreateFabric(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonCancel_Click(object sender, EventArgs e) => Close();
        private Fabric CreateFabric(int id)
        {
            Color color = Color.None;
            foreach (var elem in checkedListBoxColor.CheckedItems)
            {
                color |= (Color)elem;
            }
            return Fabric.CreateEntity(id, (FabricType)comboBoxFabric.SelectedItem!, color, Convert.ToDouble(numericUpDownMetrage.Value)); ;
        }
    }
}