﻿using Microsoft.VisualBasic.FileIO;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Atelier.Forms
{
    public partial class FormOrder : Form
    {
        private readonly IOrderRepository _orderRepository;
        public FormOrder(IOrderRepository orderRepository, IModelRepository modelRepository, IClientRepository clientRepository)
        {
            InitializeComponent();
            _orderRepository = orderRepository ??
            throw new
            ArgumentNullException(nameof(orderRepository));
            comboBoxClient.DataSource = clientRepository.ReadClients();
            comboBoxClient.DisplayMember = "FirstName";
            comboBoxClient.ValueMember = "Id";
            comboBoxStatus.DataSource = orderRepository.ReadOrders();
            comboBoxStatus.DataSource = Enum.GetValues(typeof(Status));
            ColumnModel.DataSource = modelRepository.ReadModels();
            ColumnModel.DisplayMember = "ModelType";
            ColumnModel.ValueMember = "Id";
        }
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (dataGridView1.RowCount < 1 || comboBoxClient.SelectedIndex < 0  || comboBoxStatus.SelectedIndex < 0)
                {
                    throw new Exception("Имеются незаполненные поля");
                }
                

                _orderRepository.CreateOrder(Order.CreateOperation(0, dateTimePicker1.Value, (Status)comboBoxStatus.SelectedValue,
                    (int)comboBoxClient.SelectedValue, CreateListModelOrderFromDataGrid()));
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonCancel_Click(object sender, EventArgs e) =>
        Close();
        private List<ModelOrder>
        CreateListModelOrderFromDataGrid()
        {
            var list = new List<ModelOrder>();
            foreach (DataGridViewRow row in dataGridView1.Rows)
            {
                if (row.Cells["ColumnModel"].Value == null ||
                row.Cells["ColumnCount"].Value == null)
                {
                    continue;
                }
                list.Add(ModelOrder.CreateElement(0,
                Convert.ToInt32(row.Cells["ColumnModel"].Value),
                Convert.ToInt32(row.Cells["ColumnCount"].Value)));
            }
            return list;
        }
    }
}