﻿using Atelier.Reports;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Unity;

namespace Atelier.Forms;

public partial class FormOrderReports : Form
{
    private readonly IUnityContainer _container;
    public FormOrderReports(IUnityContainer container, IOrderRepository orderRepository, IModelRepository modelRepository)
    {
        InitializeComponent();
        _container = container ??
        throw new ArgumentNullException(nameof(container));
        comboBoxModel.DataSource = modelRepository.ReadModels();
        comboBoxModel.DisplayMember = "ModelType";
        comboBoxModel.ValueMember = "Id";
    }
    private void ButtonFile_Click(object sender, EventArgs e)
    {
        var sfd = new SaveFileDialog()
        {
            Filter = "Excel Files | *.xlsx"
        };
        if (sfd.ShowDialog() != DialogResult.OK)
        {
            return;
        }
        textBoxFile.Text = sfd.FileName;
    }
    private void ButtonBuild_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxFile.Text))
            {
                throw new Exception("Отсутствует имя файла для отчета");
            }
            if (comboBoxModel.SelectedIndex < 0)
            {
                throw new Exception("Не выбран клиент");
            }
            if (dateTimePickerEnd.Value <= dateTimePickerStart.Value)
            {
                throw new Exception("Дата начала должна быть раньше даты окончания");
            }
            if
            (_container.Resolve<TableReport>().CreateTable(textBoxFile.Text,
            (int)comboBoxModel.SelectedValue!, dateTimePickerStart.Value, dateTimePickerEnd.Value))
            {
                MessageBox.Show("Документ сформирован",
                "Формирование документа",
                MessageBoxButtons.OK,
                MessageBoxIcon.Information);
            }
            else
            {
                MessageBox.Show("Возникли ошибки при формировании документа.Подробности в логах",
                "Формирование документа",
                MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при создании очета",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }
}