using Atelier;
using Atelier.Repositories;
using Atelier.Repositories.Implementations;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.Logging;
using Serilog;
using Unity;
using Unity.Lifetime;
using Unity.Microsoft.Logging;

internal static class Program
    {
        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            // To customize application configuration such as set high DPI settings or default font,
            // see https://aka.ms/applicationconfiguration.
            ApplicationConfiguration.Initialize();
            Application.Run(CreateContainer().Resolve<FormAtelier>());
        }
    private static IUnityContainer CreateContainer()
    {
        var container = new UnityContainer();
        container.AddExtension(new LoggingExtension(CreateLoggerFactory()));

        container.RegisterType<IClientRepository,ClientRepository>(new TransientLifetimeManager());
        container.RegisterType<IFabricRepository,FabricRepository>(new TransientLifetimeManager());
        container.RegisterType<IModelRepository, ModelRepository>(new TransientLifetimeManager());
        container.RegisterType<IOrderRepository,OrderRepository>(new TransientLifetimeManager());
        container.RegisterType<IStorageRepository,StorageRepository>(new TransientLifetimeManager());
        container.RegisterType<IConnectionString, ConnectionString>(new TransientLifetimeManager());
        return container;
    }
    private static LoggerFactory CreateLoggerFactory()
    {
        var loggerFactory = new LoggerFactory();
        loggerFactory.AddSerilog(new LoggerConfiguration()
        .ReadFrom.Configuration(new ConfigurationBuilder()
        .SetBasePath(Directory.GetCurrentDirectory())
        .AddJsonFile("appsettings.json")
        .Build())
        .CreateLogger());
        return loggerFactory;
    }

}
