﻿using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text.Json;

namespace Atelier.Reports
{
    internal class ChartReport
    {
        private readonly IStorageRepository _storageRepository;
        private readonly ILogger<ChartReport> _logger;

        public ChartReport(IStorageRepository storageRepository, ILogger<ChartReport> logger)
        {
            _storageRepository = storageRepository ?? throw new ArgumentNullException(nameof(storageRepository));
            _logger = logger ?? throw new ArgumentNullException(nameof(logger));
        }

        public bool CreateChart(string filePath, DateTime dateTime)
        {
            try
            {
                var data = GetData(dateTime);
                _logger.LogDebug("Data for chart: {Data}", System.Text.Json.JsonSerializer.Serialize(data));

                new PdfBuilder(filePath)
                    .AddHeader("Склад тканей")
                    .AddPieChart("Остатки тканей", data)
                    .Build();
                return true;
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка при формировании документа");
                return false;
            }
        }

        private List<(string Caption, double Value)> GetData(DateTime dateTime)
        {
            var data = _storageRepository
                .ReadStorage()
                .Where(x => x.DateStorage.Date == dateTime.Date)
                .GroupBy(x => x.FabricId, (key, group) => new { Id = key, Stock = group.Sum(x => x.StockMetrage) })
                .Select(x => (x.Id.ToString(), (double)x.Stock))
                .ToList();

            _logger.LogDebug("Raw data: {Data}", JsonSerializer.Serialize(data));
            return data;
        }

    }
}
