﻿using Atelier.Repositories;
using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;

internal class FabricRepository : IFabricRepository
{
    private readonly IConnectionString _connectionString;

    private readonly ILogger<FabricRepository> _logger;


    public FabricRepository(IConnectionString connectionString, Logger<FabricRepository> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }
    public void CreateFabric(Fabric fabric)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}", JsonConvert.SerializeObject(fabric));
        try
        {
            using var connection = new NpgsqlConnection(_connectionString.ConnectionString);
            var queryInsert = @"
INSERT INTO Fabrics (FabricType, Color, Metrage)
VALUES (@FabricType, @Color, @Metrage)";
            connection.Execute(queryInsert, fabric);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }

    }
    public void UpdateFabric(Fabric fabric)
    {
        _logger.LogInformation("Редактирование объекта");

        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(fabric));
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryUpdate = @"
UPDATE Fabrics
SET
FabricType=@FabricType,
Color=@Color,
Metrage=@Metrage
WHERE Id=@Id";
            connection.Execute(queryUpdate, fabric);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при редактировании объекта");
            throw;
        }

    }

    public void DeleteFabric(int id)
    {
        _logger.LogInformation("Удаление объекта");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryDelete = @"
DELETE FROM Fabrics
WHERE Id=@id";
            connection.Execute(queryDelete, new { id });
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при удалении объекта");
            throw;
        }
    }

    public Fabric ReadFabricById(int id)
    {
        _logger.LogInformation("Получение объекта по идентификатору");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = @"
SELECT * FROM Fabrics
WHERE Id=@id";
            var fabric = connection.QueryFirst<Fabric>(querySelect, new
            {
                id
            });
            _logger.LogDebug("Найденный объект: {json}",
            JsonConvert.SerializeObject(fabric));
            return fabric;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при поиске объекта");
            throw;
        }
    }

    public IEnumerable<Fabric> ReadFabrics()
    {
        _logger.LogInformation("Получение всех объектов");
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = "SELECT * FROM Fabrics";
            var fabrics = connection.Query<Fabric>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}",
            JsonConvert.SerializeObject(fabrics));
            return fabrics;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении объектов");
            throw;
        }

    }


}