﻿using Atelier.Repositories;
using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;
using Serilog.Core;


internal class OrderRepository : IOrderRepository
{
    private readonly IConnectionString _connectionString;
    private readonly ILogger<Order> _logger;
    public OrderRepository(IConnectionString connectionString,
    ILogger<Order> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }

    public void CreateOrder(Order order)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(order));
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            connection.Open();
            using var transaction = connection.BeginTransaction();
            var queryInsert = @"
INSERT INTO Orders (Date, Status, ClientId)
VALUES (@Date, @Status, @ClientId);
SELECT MAX(Id) FROM Orders";
            var orderId =
            connection.QueryFirst<int>(queryInsert, order, transaction);
            var querySubInsert = @"
INSERT INTO ModelOrder (OrderId, ModelId, Count)
VALUES (@OrderId,@ModelId, @Count)";
            foreach (var elem in order.ModelOrder)
            {
                connection.Execute(querySubInsert, new
                {
                    orderId,
                    elem.ModelId,
                    elem.Count
                }, transaction);
            }
            transaction.Commit();
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }

    }
    public void DeleteOrder(int id)
    {
        _logger.LogInformation("Удаление объекта");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryDelete = @"
DELETE FROM Orders
WHERE Id=@id";
            connection.Execute(queryDelete, new { id });
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при удалении объекта");
            throw;
        }

    }
    public IEnumerable<Order> ReadOrders(int? id = null, DateTime?dateForm = null, DateTime? dateTo = null,
        Status? status = null, int? clientId = null)
    {
        _logger.LogInformation("Получение всех объектов");
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = @"SELECT * FROM Orders";
            var orders =
            connection.Query<Order>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}",
            JsonConvert.SerializeObject(orders));
            return orders;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении объектов");
            throw;
        }

    }
}
