﻿using Atelier.Repositories;
using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Npgsql;

internal class StorageRepository : IStorageRepository
{
    private readonly IConnectionString _connectionString;
    private readonly ILogger<Storage> _logger;
    public StorageRepository(IConnectionString connectionString,
    ILogger<Storage> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }
    public void CreateStorage(Storage storage)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}", JsonConvert.SerializeObject(storage));
        try
        {
            using var connection = new NpgsqlConnection(_connectionString.ConnectionString);
            var queryInsert = @"
INSERT INTO Storages (FabricId, StockMetrage, DateStorage)
VALUES (@FabricId, @StockMetrage, @DateStorage)";
            connection.Execute(queryInsert, storage);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }
    }

    public void DeleteStorage(int id)
    {
        _logger.LogInformation("Удаление объекта");
        _logger.LogDebug("Объект: {id}", id);
        try
        {
            using var connection = new
            NpgsqlConnection(_connectionString.ConnectionString);
            var queryDelete = @"
DELETE FROM Storages
WHERE Id=@id";
            connection.Execute(queryDelete, new { id });
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при удалении объекта");
            throw;
        }
    }
    public IEnumerable<Storage> ReadStorage(int? fabricId = null, double? minStockMetrage = null, double? StockMetrage = null)
    {
        _logger.LogInformation("Получение всех данных о складе");
        try
        {
            using var connection = new NpgsqlConnection(_connectionString.ConnectionString);
            var querySelect = "SELECT * FROM Storages";
            var storages = connection.Query<Storage>(querySelect).ToList();

            _logger.LogDebug("Полученные данные о складе: {json}", JsonConvert.SerializeObject(storages));
            return storages;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении данных о складе");
            throw;
        }
    }
}
